/*
 * Velvet Jacket Dashboard Widget JavaScript
 * Copyright (c) James O'Gorman 2005
 * www.jamesog.net james@jamesog.net
 */
 
var iRefreshTime;
var sCoverType;
var sTiming;
var iRefreshInterval; // This is for the timer, not the preference!
var imageList; // This holds the array of covers
var curImage; // The currently displayed image (array ref, not string)

function setup()
{
	// Find the option forms and put them into vars to use in a moment
	var optImageType = document.getElementById("imageType");
	var optRefreshTime = document.getElementById("refreshTime");
	var optTiming = document.getElementById("timingMenu");
	
	if(window.widget)
	{
		// Retrieve saved options (if any)
		sCoverType = widget.preferenceForKey("coverType");
		iRefreshTime = widget.preferenceForKey("refreshTime");
		sTiming = widget.preferenceForKey("timing");
		
		// Tell Dashboard to only run the timer when it's showing
		widget.onshow = function onShow() {		// when Dashboard is triggered
			setRefreshTimer();
		}
		widget.onremove = function onRemove() {	// when widget removed
			clearRefreshTimer();
		}
		widget.onhide = function onHide() {		// when Dashboard hidden
			clearRefreshTimer();
		}
	}
	
	// Set default if no prefs found
	if(!sCoverType)
		sCoverType = "Covers";
	
	if(!iRefreshTime)
		iRefreshTime = 5;
	
	if(!sTiming)
		sTiming = "secs";
	
	// Apply the prefs to the option elements
	optRefreshTime.value = iRefreshTime;
	
	switch(sCoverType) {
		case "Covers":
			optImageType.selectedIndex = 0;
			break;
		case "Artwork":
			optImageType.selectedIndex = 1;
			break;
	}
	
	switch(sTiming) {
		case "secs":
			optTiming.selectedIndex = 0;
			break;
		case "mins":
			optTiming.selectedIndex = 1;
			break;
	}		
	
	changeImage();
}

function imageChanged(elem)
{
	sCoverType = elem;
	if (window.widget)
		widget.setPreferenceForKey(elem, "coverType");
		
	changeImage();							// Reload the image after the change
	clearRefreshTimer(); 					// Reset the current timer
	setTimeout("setRefreshTimer()", 2000);	// And start it again (we need to wait 2 secs or
											// the timer does not start again)  
}

function refreshChanged(elem)
{
	iRefreshTime = elem;
	if (window.widget)
		widget.setPreferenceForKey(elem, "refreshTime");
		
	changeImage();							// Reload the image after the change		
	clearRefreshTimer(); 					// Reset the current timer
	setTimeout("setRefreshTimer()", 2000);	// And start it again (we need to wait 2 secs or
											// the timer does not start again)    
}

function timingChanged(elem)
{
	sTiming = elem;
	if(window.widget)
		widget.setPreferenceForKey(elem, "timing");

	changeImage();							// Reload the image after the change	
	clearRefreshTimer(); 					// Reset the current timer
	setTimeout("setRefreshTimer()", 2000);	// And start it again (we need to wait 2 secs or
											// the timer does not start again)  
}

function getImageList(lsCoverType)
{
	httpreq = new XMLHttpRequest();
	httpreq.open("GET", "http://www.velvet-jacket.com/"+lsCoverType+".list", false);
	httpreq.send(null);
	var list = httpreq.responseText;
	var imageList = new Array();
	imageList = list.split("\n");
	imageList.pop();
	return imageList;
}

function changeImage()
{
	imageList = getImageList(sCoverType);
	curImage = Math.floor(Math.random() * imageList.length);
	var imageUrl = "http://www.velvet-jacket.com/"+imageList[curImage];
	document.getElementById("cover").src = imageUrl;
}

function setRefreshTimer()
{
	var time;
	switch(sTiming) {
		case "secs":
			time = 1;
			break;
		case "mins":
			time = 60;
			break;
	}
	
	if (iRefreshInterval == null)
		iRefreshInterval = setInterval("changeImage()", iRefreshTime*time*1000);
}

function clearRefreshTimer()
{
	if (iRefreshInterval != null) {
		clearInterval(iRefreshInterval);
		iRefreshInterval = null;
	}
}

function openPage()
{
	var imgName = imageList[curImage];
	if (sCoverType == "Covers")
		var pageName = imgName.replace(/_t.jpg$/, ".shtml");
	else if (sCoverType == "Artwork")
	{
		var result = imgName.match(/^cov_([0-9]{2}).jpg$/);
		for (i = 1; i < 13; i++)
		{
			if (i*15 >= result[1] && i == 1)
			{
				pageName = "gallery.shtml";
				break;
			}
			else if (i*15 >= result[1] && i > 1)
			{
				pageName = "gallery"+i+".shtml";
				break;
			}
		}
	}
			
	if(widget)
		widget.openURL('http://www.velvet-jacket.com/'+pageName);
}

function openVJ()
{
	if(widget)
	{
		widget.openURL('http://www.velvet-jacket.com');
	}
}

/*
 * Hiding and showing preferences
 */

function showPrefs()
{
	var front = document.getElementById("front");
	var back = document.getElementById("back");
	
	if (window.widget)
		widget.prepareForTransition("ToBack");		// freezes the widget so that you can change it without the user noticing
	
	front.style.display="none";		// hide the front
	back.style.display="block";		// show the back
	
	if (window.widget)
		setTimeout ('widget.performTransition();', 0);		// and flip the widget over	

	document.getElementById('fliprollie').style.display = 'none';  // clean up the front side - hide the circle behind the info button

}


// hidePrefs() is called by the done button on the back side of the widget.  It performs the opposite transition
// as showPrefs() does.

function hidePrefs()
{
	var front = document.getElementById("front");
	var back = document.getElementById("back");
	
	if (window.widget)
		widget.prepareForTransition("ToFront");		// freezes the widget and prepares it for the flip back to the front
	
	back.style.display="none";			// hide the back
	front.style.display="block";		// show the front
	
	if (window.widget)
		setTimeout ('widget.performTransition();', 0);		// and flip the widget back to the front
}

var flipShown = false;		// a flag used to signify if the flipper is currently shown or not.

var animation = {duration:0, starttime:0, to:1.0, now:0.0, from:0.0, firstElement:null, timer:null};


function mousemove (event)
{
	if (!flipShown)			// if the preferences flipper is not already showing...
	{
		if (animation.timer != null)			// reset the animation timer value, in case a value was left behind
		{
			clearInterval (animation.timer);
			animation.timer  = null;
		}
		
		var starttime = (new Date).getTime() - 13; 		// set it back one frame
		
		animation.duration = 500;												// animation time, in ms
		animation.starttime = starttime;										// specify the start time
		animation.firstElement = document.getElementById ('flip');		// specify the element to fade
		animation.timer = setInterval ("animate();", 13);						// set the animation function
		animation.from = animation.now;											// beginning opacity (not ness. 0)
		animation.to = 1.0;														// final opacity
		animate();																// begin animation
		flipShown = true;														// mark the flipper as animated
	}
}

function mouseexit (event)
{
	if (flipShown)
	{
		// fade in the flip widget
		if (animation.timer != null)
		{
			clearInterval (animation.timer);
			animation.timer  = null;
		}
		
		var starttime = (new Date).getTime() - 13;
		
		animation.duration = 500;
		animation.starttime = starttime;
		animation.firstElement = document.getElementById ('flip');
		animation.timer = setInterval ("animate();", 13);
		animation.from = animation.now;
		animation.to = 0.0;
		animate();
		flipShown = false;
	}
}

// animate() performs the fade animation for the preferences flipper. It uses the opacity CSS property to simulate a fade.

function animate()
{
	var T;
	var ease;
	var time = (new Date).getTime();
		
	
	T = limit_3(time-animation.starttime, 0, animation.duration);
	
	if (T >= animation.duration)
	{
		clearInterval (animation.timer);
		animation.timer = null;
		animation.now = animation.to;
	}
	else
	{
		ease = 0.5 - (0.5 * Math.cos(Math.PI * T / animation.duration));
		animation.now = computeNextFloat (animation.from, animation.to, ease);
	}
	
	animation.firstElement.style.opacity = animation.now;
}


// these functions are utilities used by animate()

function limit_3 (a, b, c)
{
    return a < b ? b : (a > c ? c : a);
}

function computeNextFloat (from, to, ease)
{
    return from + (to - from) * ease;
}

// these functions are called when the info button itself receives onmouseover and onmouseout events

function enterflip(event)
{
	document.getElementById('fliprollie').style.display = 'block';
}

function exitflip(event)
{
	document.getElementById('fliprollie').style.display = 'none';
}